@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2024 Roberto Alsina and others.
+# Copyright © 2012-2025 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -38,12 +38,11 @@ from urllib.parse import urlsplit, urlunsplit
 import dateutil.tz
 import dateutil.zoneinfo
 from mako.template import Template
-from pkg_resources import resource_filename
 
 import nikola
 from nikola.nikola import DEFAULT_INDEX_READ_MORE_LINK, DEFAULT_FEED_READ_MORE_LINK, LEGAL_VALUES
 from nikola.plugin_categories import Command
-from nikola.utils import ask, ask_yesno, get_logger, makedirs, load_messages
+from nikola.utils import ask, ask_yesno, get_logger, makedirs, load_messages, pkg_resources_path
 from nikola.packages.tzlocal import get_localzone
 
 
@@ -273,13 +272,13 @@ class CommandInit(Command):
     @classmethod
     def copy_sample_site(cls, target):
         """Copy sample site data to target directory."""
-        src = resource_filename('nikola', os.path.join('data', 'samplesite'))
+        src = pkg_resources_path('nikola', os.path.join('data', 'samplesite'))
         shutil.copytree(src, target)
 
     @staticmethod
     def create_configuration(target):
         """Create configuration file."""
-        template_path = resource_filename('nikola', 'conf.py.in')
+        template_path = pkg_resources_path('nikola', 'conf.py.in')
         conf_template = Template(filename=template_path)
         conf_path = os.path.join(target, 'conf.py')
         with io.open(conf_path, 'w+', encoding='utf8') as fd:
@@ -288,7 +287,7 @@ class CommandInit(Command):
     @staticmethod
     def create_configuration_to_string():
         """Return configuration file as a string."""
-        template_path = resource_filename('nikola', 'conf.py.in')
+        template_path = pkg_resources_path('nikola', 'conf.py.in')
         conf_template = Template(filename=template_path)
         return conf_template.render(**prepare_config(SAMPLE_CONF))
 
